@@ -8,6 +8,6 @@ class CheckTest(abc.ABC):
     def create_instance(self, name: str) -> Check:
         pass
 
-    def test_name_passing(self) -> None:
+    def test_the_configured_name_is_used(self) -> None:
         name = "checktestname"
         assert self.create_instance(name).name == name
